import { Component } from "react";
import { View, Text, Swiper, SwiperItem, Image } from "@tarojs/components";
import { AtIcon } from "taro-ui";
import {
  getProductDetail,
  getProductLikeList,
  getProductPromotion,
  getShareJump,
  bindShareJump,
  getShareSwitch,
} from "../../../service";
import { handleLog } from "../../../common/track";
import { isDebounce } from "../../../common/debounce";
import "./index.less";
import Taro from "@tarojs/taro";
import productDetailIcon from "../../../images/productDetail/productDetailIcon.png";
import like from "../../../images/productDetail/like.png";
import home from "../../../images/nav/home.png";
import selfBuy from "../../../images/productDetail/selfBuy.png";
import share from "../../../images/productDetail/share.png";
import ProductCard from "../../../components/ProductCard"; //产品卡片
import Modal from "../../../components/Modal"; //弹窗
import ShareModal from "../../../components/shareModal"; //分享弹窗
import SignModal from "../../../components/signModal"; //签约弹窗
export default class Index extends Component {
  state = {
    id: "", //商品id
    isShare: false, //是否是分享
    isOpened: "", //是否打开弹窗
    productDetail: [], //商品详情
    productLikeList: [], //推荐商品列表
    productPromotion: [], //商品推广转链
    isSeckill: false, //是否是专项区域页面
    tagTitle: "", //专项跳转标题
    shareJump: "", //分享跳转标识
    shareTitle: "", //分享标题
    shareUserId: "", //分享用户id
    isShowBack: false, //是否显示返回
    shareSwitch: 1, //分享返回开关
  };
  // 获取产品详情的方法
  fetchProductDetails = async (id) => {
    const res = await getProductDetail({
      goods_id: id,
    });
    this.setState({
      productDetail: res,
    });
  };
  // 获取猜你喜欢列表
  getProductLikeList = async () => {
    const res = await getProductLikeList();
    this.setState({
      productLikeList: res,
    });
  };
  // 获取商品推广转链
  getProductPromotion = async () => {
    const res = await getProductPromotion({
      goods_id: [this.state.id],
      item_id: [this.state.productDetail.item_id],
      material_type: 1, //1:自购省,2:红包购买
    });
    this.setState({
      productPromotion:
        res.alibaba_idle_affiliate_general_link_convert_response.result.result,
    });
  };
  componentDidMount() {
    // 隐藏右上角分享按钮
    Taro.hideShareMenu({
      menus: ["shareAppMessage", "shareTimeline"],
    });
    let {
      id,
      isShare,
      isSeckill,
      shareJump,
      shareUserId,
      tagTitle,
      shareType,
      isShowBack,
      share_unique_value,
    } = Taro.getCurrentInstance().router.params;
    shareJump = shareJump || share_unique_value;
    let session_key = Taro.getStorageSync("session_key");
    let userInfo = Taro.getStorageSync("userInfo");
    let isShowSign = Taro.getStorageSync("isShowSign");
    this.setState(
      {
        id,
        isShare: isShare === "true",
        isSeckill: isSeckill === "true",
        shareUserId: shareUserId,
        tagTitle: tagTitle,
        isShowBack: isShowBack === "true" || false,
      },
      () => {
        // 分享页面才判断是否展示
        if (this.state.isShare) {
          this.setState(
            {
              shareSwitch: 0,
            },
            () => {
              // 获取分享开关
              this.getShareSwitch();
            }
          );
        }
        // 获取分享跳转标识
        shareJump &&
          Taro.setStorage({
            key: "shareJump",
            data: shareJump,
          });
        shareType &&
          Taro.setStorage({
            key: "shareType",
            data: shareType,
          });
        this.fetchProductDetails(id); //获取产品详情
        this.getProductLikeList(); //获取猜你喜欢列表
        if (session_key && shareJump) {
          this.bindShareJump(); //绑定分享跳转标识
        }
        // 埋点
        if (this.state.isSeckill) {
          handleLog({
            event_type: "direct_to_product",
            event_type_title: "进入商品详情页",
            goods_id: Number(this.state.id),
            shareUserId: this.state.shareUserId,
          }); //埋点
        }
        // 判断是否显示签约弹窗
        if (
          session_key &&
          isShowSign !== false &&
          userInfo &&
          userInfo.user_identity == 0 &&
          !this.state.isShare
        ) {
          this.setState({
            isOpened: "sign",
          });
        }
      }
    );
  }
  // 获取分享开关
  getShareSwitch = async () => {
    const res = await getShareSwitch({
      key: "share_switch",
    });
    this.setState({
      shareSwitch: Number(res.value),
    });
  };
  // 复制商品编号
  handleCopy = (text) => {
    Taro.setClipboardData({
      data: text,
      success: () => {
        Taro.showToast({
          title: "复制成功",
          icon: "success",
        });
      },
    });
  };

  // 添加跳转首页方法
  handleToHome = () => {
    Taro.switchTab({
      url: "/pages/index/index",
    });
  };

  // 立即购买
  handleBuy = async () => {
    this.setState({
      isOpened: "self",
    });
    if (!this.state.productPromotion.short_tpwd) {
      await this.getProductPromotion();
    }
  };
  // 绑定分享跳转标识
  bindShareJump = async () => {
    let shareJump = Taro.getStorageSync("shareJump");
    await bindShareJump({
      share_type: 1,
      share_unique_value: shareJump,
    });
    Taro.removeStorageSync("shareJump");
    Taro.removeStorageSync("shareType");
  };
  // 分享
  openSharePopup = async () => {
    if (!isDebounce(500)) return; // 如果在500ms内重复触发，直接返回
    let shareUserId = "";
    if (Taro.getStorageSync("loginInfo")) {
      shareUserId = Taro.getStorageSync("loginInfo").id;
    }
    // 使用 encodeURIComponent 编码商品详情数据
    const encodedProductDetail = encodeURIComponent(
      JSON.stringify(this.state.productDetail)
    );
    Taro.navigateTo({
      url: `/pages/indexSub/sharePage/index?isSeckill=${this.state.isSeckill}&tagTitle=${this.state.tagTitle}&productDetail=${encodedProductDetail}&shareUserId=${shareUserId}`,
    });
    // 埋点
    if (this.state.isSeckill) {
      handleLog({
        event_type: "share_product_link",
        event_type_title: "点击分享赚",
        goods_id: Number(this.state.id),
        shareUserId: this.state.shareUserId,
      });
    }
    // return
    // const res = await getShareJump({
    //   share_type: 1,
    //   share_id: this.state.id,
    // });
    // this.setState({
    //   shareJump: res.share_unique_value,
    //   isOpened: "share",
    // });
    // 埋点
  };
  // 设置分享标题
  // handleShareTitleChange = (newTitle) => {
  //   this.setState({
  //     shareTitle: newTitle,
  //   });
  // };
  // 配置分享内容
  // onShareAppMessage() {
  //   return {
  //     title: this.state.shareTitle || this.state.productDetail.item_title,
  //     path: `/pages/indexSub/productDetail/index?id=${this.state.id}&&isShare=true&&isSeckill=${this.state.isSeckill}&&shareJump=${this.state.shareJump}&&tagTitle=${this.state.tagTitle}&&shareType=1`,
  //     imageUrl: this.state.productDetail.images[0].img,
  //   };
  // }
  // 添加返回方法
  handleBack = () => {
    const pages = Taro.getCurrentPages();
    if (pages.length > 1) {
      Taro.navigateBack();
    } else {
      Taro.switchTab({
        url: "/pages/index/index",
      });
    }
  };
  render() {
    const { productDetail, tagTitle } = this.state;
    return (
      <View
        className="index"
        style={{ paddingTop: Taro.navigationBarHeight + "px" }}
      >
        {this.state.shareSwitch == 1 && (
          <View className="back-btn" onClick={this.handleBack}>
            <AtIcon value="chevron-left" size="24" color="#999999"></AtIcon>
          </View>
        )}
        {this.state.isShowBack && (
          <View className="back-btn" onClick={this.handleBack}>
            <AtIcon value="chevron-left" size="24" color="#999999"></AtIcon>
          </View>
        )}
        {/* 轮播图 */}
        <Swiper className="swiper" autoplay circular>
          {productDetail.images &&
            productDetail.images.map((imageObj, index) => (
              <SwiperItem key={index}>
                <Image
                  className="swiper-img"
                  src={imageObj.img}
                  mode="aspectFill"
                />
              </SwiperItem>
            ))}
        </Swiper>
        {/* 商品详情模块 */}
        <View className="product-info">
          {/* 商品名称 */}
          <Text className="product-name">
            <Text className="self-tag">
              {this.state.isSeckill ? tagTitle : "自营"}
            </Text>
            {productDetail.item_title}
          </Text>

          {/* 价格和标签行 */}
          <View className="price-tag-row">
            {/* 价格区域 */}
            <View className="price-box">
              <Text className="current-price">
                <Text className="currency">¥</Text>
                {productDetail.reserve_price}
              </Text>
              {productDetail.original_price != "0.00" && (
                <Text className="original-price">
                  ¥{productDetail.original_price}
                </Text>
              )}
            </View>
            {/* 标签区域 */}
            {!this.state.isShare && (
              <View className="tag-box">
                <Text className="tag">
                  分享赚￥{productDetail.estimated_commission_promotion}
                </Text>
              </View>
            )}
          </View>

          {/* 分割线 */}
          <View className="divider" />

          {/* 商品编号行 */}
          <View className="product-number-row">
            <Text className="number-label">
              商品编号：{productDetail.goods_number}
            </Text>
            <Text
              className="copy-btn"
              onClick={() => this.handleCopy(productDetail.goods_number)}
            >
              复制
            </Text>
          </View>
        </View>
        {/* 商品标签模块 */}
        <View className="product-tag-row">
          <View className="tag-item">
            <Image src={productDetailIcon} mode="aspectFit" />
            <Text className="tag-text">渔市商品</Text>
          </View>
          <View className="tag-item">
            <Image src={productDetailIcon} mode="aspectFit" />
            <Text className="tag-text">品质保证</Text>
          </View>
          <View className="tag-item">
            <Image src={productDetailIcon} mode="aspectFit" />
            <Text className="tag-text">无忧售后</Text>
          </View>
        </View>
        {/* 产品详情 */}
        <View className="product-detail">
          <View className="title">商品描述</View>
          {productDetail.item_desc && (
            <Text className="content">{productDetail.item_desc}</Text>
          )}
        </View>
        {/* 猜你喜欢 */}
        <View className="guess-you-like">
          <Image src={like} mode="aspectFit" />
          <Text className="title">猜你喜欢</Text>
        </View>
        {/* 猜你喜欢产品列表 */}
        <View className="product-card-list">
          {this.state.productLikeList.map((product) => (
            <ProductCard
              key={product.id}
              product={product}
              isShowBack={this.state.isShowBack}
              isShare={this.state.isShare}
            />
          ))}
        </View>
        {/* 底部购买模块 */}
        <View
          className={`bottom-buy ${this.state.isShare ? "share-active" : ""}`}
        >
          {!this.state.isShare && (
            <View onClick={this.handleToHome} className="bottom-buy-left">
              <Image src={home} mode="aspectFit" />
              <Text className="bottom-buy-text">首页</Text>
            </View>
          )}
          <View className="bottom-buy-right">
            {!this.state.isShare ? (
              <>
                <View
                  onClick={this.openSharePopup}
                  className="bottom-buy-right-self"
                >
                  <Image src={share} mode="aspectFit" />
                  <Text className="bottom-buy-text">分享赚</Text>
                </View>
                {Number(productDetail.estimated_commission_buy) > 0 ? (
                  <View
                    onClick={this.handleBuy}
                    className="bottom-buy-right-share"
                  >
                    <Image src={selfBuy} mode="aspectFit" />
                    <Text className="bottom-buy-text">自购省</Text>
                  </View>
                ) : (
                  <View
                    onClick={this.handleBuy}
                    className="bottom-buy-right-share"
                  >
                    <Text className="bottom-buy-text">立即购买</Text>
                  </View>
                )}
              </>
            ) : (
              <View onClick={this.handleBuy} className="bottom-buy-right-btn">
                <Text className="bottom-buy-text">立即购买</Text>
              </View>
            )}
          </View>
        </View>
        {/* 自购弹窗 */}
        <Modal
          title="闲鱼口令"
          isOpened={this.state.isOpened == "self"}
          productPromotion={this.state.productPromotion}
          linkText={this.state.productPromotion.short_tpwd}
          id={this.state.id}
          shareUserId={this.state.shareUserId}
          isSeckill={this.state.isSeckill}
        />
        {/* 分享弹窗 */}
        {/* {this.state.isOpened == "share" && (
          <ShareModal
            onClose={() => {
              this.setState({
                isOpened: "",
                shareTitle: productDetail.item_title,
              });
            }}
            isOpened={this.state.isOpened == "share"}
            product={this.state.productDetail}
            onShareTitleChange={this.handleShareTitleChange}
          />
        )} */}
        {/* 签约弹窗 */}
        <SignModal
          isOpened={this.state.isOpened == "sign"}
          onClose={() => {
            this.setState({
              isOpened: "",
            });
          }}
        />
      </View>
    );
  }
}
