import { Component } from "react";
import Taro from "@tarojs/taro";
import { View } from "@tarojs/components";
import { AtIcon } from "taro-ui";
import "./index.less";
import ProductList from "../../../components/index/ProductList";
import { getSearchProductList } from "../../../service";
export default class Index extends Component {
  state = {
    productList: [],
    page: 1,
    totalPages: 1,
    loading: false,
    keyword: "",
    isNoMore: false, // 是否没有更多
  };
  componentDidMount() {
    const { keyword }  = Taro.getCurrentInstance().router.params||"";
    this.setState({ keyword }, () => {
      this.getSearchProductList(true);
    });
  }
  // 获取商品列表
  getSearchProductList = async (isAdd = false) => {
    const { page } = this.state;
    this.setState({ loading: true });

    const res = await getSearchProductList({
      search_name: this.state.keyword,
      page,
      page_size: 10,
    });

    this.setState((prevState) => ({
      productList: isAdd
        ? res.goods_list
        : [...prevState.productList, ...res.goods_list],
      totalPages: res.total_pages,
      loading: false,
      isNoMore: res.total_pages <= page,
    }));
  };
  // 页面上拉触底
  onReachBottom = () => {
    const { page, totalPages, loading } = this.state;
    if (page < totalPages && !loading) {
      this.setState(
        (prevState) => ({ page: prevState.page + 1 }),
        () => this.getSearchProductList()
      );
    }
  };
  render() {
    const { productList, loading, isNoMore } = this.state;
    
    return (
      <View className="index">
        {/* 无搜索结果提示 */}
        {!loading && productList.length === 0 && (
          <View className="empty-result">
            <AtIcon value="search" size="30" color="#999"></AtIcon>
            <View className="empty-text">暂无相关商品</View>
          </View>
        )}
        {/* 搜索列表 */}
        <ProductList
          productList={productList}
          loading={loading}
          isNoMore={isNoMore}
          isEmpty={productList.length === 0}
        ></ProductList>
      </View>
    );
  }
}
