import { Component } from "react";
import { View, Image, Button, Input } from "@tarojs/components";
import {
  getShareJump,
  getProductDetail,
  refreshToken,
} from "../../../service/index";
import Taro from "@tarojs/taro";
import "./index.less";

export default class Index extends Component {
  state = {
    id: "", //商品id(专题列表分享过来的)
    shareTitle: "", //分享标题
    productDetail: {}, //商品详情
    isSeckill: false, //是否是秒杀商品
    shareJump: "", //分享链接
    tagTitle: "", //标签标题
    shareUserId: "", //分享用户id
    share_scheme_link: "", //分享方案链接
  };
  componentDidMount() {
    Taro.hideShareMenu({
      menus: ["shareAppMessage", "shareTimeline"],
    });
    const { isSeckill, tagTitle, productDetail, shareUserId, id } =
      Taro.getCurrentInstance().router.params;
    this.setState(
      {
        isSeckill: isSeckill === "true",
        tagTitle,
        productDetail: productDetail
          ? JSON.parse(decodeURIComponent(productDetail))
          : {},
        shareTitle: productDetail
          ? JSON.parse(decodeURIComponent(productDetail)).item_title
          : "",
        shareUserId,
        id: id,
      },
      () => {
        this.getProductDetail(id);
        this.getShareJump(id);
      }
    );
  }
  // 获取商品详情
  getProductDetail = async (id = "") => {
    const res = await getProductDetail({
      goods_id: id || this.state.productDetail.id,
    });
    this.setState({
      productDetail: res,
      shareTitle: res.item_title,
    });
  };
  // 重新获取分享跳转标识
  regain = async () => {
    const res = await refreshToken();
    this.getShareJump();
  };
  // 获取分享跳转标识
  getShareJump = async (id = "") => {
    Taro.showLoading({
      title: "加载中...",
    });
    // 设置分享路径
    const share_extend = JSON.stringify({
      path: `pages/indexSub/productDetail/index?id=${
        id || this.state.productDetail.id
      }&isShare=true&isSeckill=${
        this.state.isSeckill
      }&shareType=11&&shareUserId=${this.state.shareUserId}`,
    });
    const res = await getShareJump({
      share_type: 11,
      share_id: id || this.state.productDetail.id,
      share_extend,
    });
    if (res.code == 200) {
      this.setState({
        shareJump: res.data.share_unique_value,
        share_scheme_link: res.data.share_scheme_link,
      });
    }
    Taro.hideLoading();
  };
  // 设置分享标题
  handleShareTitleChange = (newTitle) => {
    this.setState({
      shareTitle: newTitle.detail.value,
    });
  };
  // 保存图片到手机
  handleSaveImage = () => {
    Taro.getSetting({
      success: (res) => {
        if (!res.authSetting["scope.writePhotosAlbum"]) {
          Taro.authorize({
            scope: "scope.writePhotosAlbum",
            success: () => {
              this.saveImage();
            },
            fail: () => {
              Taro.showModal({
                title: "提示",
                content: "需要您授权保存图片到相册",
                success: (modalRes) => {
                  if (modalRes.confirm) {
                    Taro.openSetting();
                  }
                },
              });
            },
          });
        } else {
          this.saveImage();
        }
      },
    });
  };

  saveImage = async () => {
    Taro.showLoading({
      title: "保存中...",
    });
    const { images } = this.state.productDetail;
    try {
      for (const image of images) {
        // 转换图片链接从 http 到 https
        const imgUrl = image.img.startsWith("http:")
          ? image.img.replace("http:", "https:")
          : image.img;
        // 先获取图片信息
        const imageInfo = await Taro.getImageInfo({
          src: imgUrl,
        });
        // 使用图片路径保存
        await Taro.saveImageToPhotosAlbum({
          filePath: imageInfo.path,
        });
      }
      // 全部保存成功后提示
      Taro.showToast({
        title: "所有图片保存成功",
        icon: "success",
        duration: 2000,
      });
    } catch (error) {
      Taro.showToast({
        title: "保存失败",
        icon: "none",
        duration: 2000,
      });
    }
  };
  // 复制全部内容
  handleCopyAll = () => {
    Taro.setClipboardData({
      data: `${this.state.shareTitle}\n${this.state.share_scheme_link}`,
    });
  };
  // 复制标题
  handleCopyTitle = () => {
    Taro.setClipboardData({
      data: this.state.shareTitle,
      success: () => {
        Taro.showToast({
          title: "标题复制成功",
          icon: "none",
          duration: 1500,
        });
      },
    });
  };
  // 复制链接
  handleCopyLink = () => {
    Taro.setClipboardData({
      data: this.state.share_scheme_link,
      success: () => {
        Taro.showToast({
          title: "链接复制成功",
          icon: "none",
          duration: 1500,
        });
      },
    });
  };
  // 配置分享内容
  onShareAppMessage() {
    return {
      title: this.state.shareTitle || this.state.productDetail.item_title,
      path: `/pages/indexSub/productDetail/index?id=${this.state.productDetail.id}&&isShare=true&&isSeckill=${this.state.isSeckill}&&shareJump=${this.state.shareJump}&&tagTitle=${this.state.tagTitle}&&shareType=11&&shareUserId=${this.state.shareUserId}`,
      imageUrl: this.state.productDetail.images[0].img,
    };
  }
  render() {
    const { productDetail } = this.state;
    return (
      <View className="index">
        {/* 图片素材盒子 */}
        <View className="image-box">
          <View className="image-box-top">
            <View className="image-box-title">图片素材</View>
            <View className="image-box-save" onClick={this.handleSaveImage}>
              保存图片
            </View>
          </View>
          {productDetail.images && (
            <View className="image-box-content">
              {this.state.productDetail.images.map((item, index) => (
                <Image
                  className="image-box-content-item"
                  key={index}
                  src={item.img}
                  mode="aspectFill"
                />
              ))}
            </View>
          )}
        </View>
        {/* 文案素材盒子 */}
        <View className="text-box">
          <View className="text-box-top">
            <View className="text-box-title">文案素材</View>
            <View onClick={this.handleCopyAll} className="text-box-save">
              复制全部内容
            </View>
          </View>
          <View className="text-box-content">
            {/* 商品标题盒子 */}
            <View className="text-box-content-title">
              <View className="text-box-content-title-top">
                <View className="text-box-content-title-top-title">
                  商品标题
                </View>
                <View
                  onClick={this.handleCopyTitle}
                  className="text-box-content-title-top-copy"
                >
                  复制标题
                </View>
              </View>
              {/* 分享标题输入框 */}
              <View className="text-box-content-title-input">
                <Input
                  onInput={this.handleShareTitleChange}
                  className="input"
                  value={this.state.shareTitle}
                />
              </View>
            </View>
            {/* 商品链接盒子 */}
            <View className="text-box-content-link">
              <View className="text-box-content-link-top">
                <View className="text-box-content-link-top-title">
                  商品链接
                </View>
              </View>
              {/* 商品链接 */}
              <View className="text-box-content-link-bottom">
                <Input
                  onInput={this.handleShareTitleChange}
                  className="linkInput"
                  value={
                    this.state.share_scheme_link ||
                    "商品链接获取失败，请重新获取"
                  }
                  disabled
                />
                <View className="copy-box">
                  <View className="copy-box-line"></View>
                  {this.state.share_scheme_link ? (
                    <Image
                      onClick={this.handleCopyLink}
                      className="copy-box-icon"
                      src="https://yushi.tos-cn-beijing.volces.com/productDetail/copy.png"
                    />
                  ) : (
                    <View className="getLink" onClick={this.regain}>
                      重新获取
                    </View>
                  )}
                </View>
              </View>
            </View>
          </View>
        </View>
        {/* 分享按钮 */}
        {this.state.shareJump && (
          <Button
            className="share-button"
            openType="share"
            onClick={this.handleShare}
          >
            直接分享商品卡片到聊天框
          </Button>
        )}
      </View>
    );
  }
}
