import { Component } from "react";
import { View, Text, Image } from "@tarojs/components";
import { AtIcon } from "taro-ui";
import { getVipInfo, getUserAgreement } from "../../service";
import { get_my_worker_info } from "../../service/money_api";
import Taro from "@tarojs/taro";
import "./index.less";
import vip from "../../images/member/vip.png";
import home from "../../images/nav/home.png";
import toDetail from "../../images/member/toDetail.png";
import warning from "../../images/member/warning.png";
import withdrawable from "../../images/member/withdrawable.png";
import order from "../../images/member/order.png";
import partner from "../../images/member/myPartner.png";
import calculator from "../../images/member/calculator.png";
import InstructionModal from "../../components/instructionModal";
export default class Index extends Component {
  state = {
    vipInfo: {
      users: { name: "去登录", icon: 'https://yushi.tos-cn-beijing.volces.com/mine/avatar.png',user_identity_translate:0 },//user_identity_translate 0：默认未认证，1：已认证成功，2：认证失败,3：认证中
      earnings: { store_earnings_now: 0, store_earnings_all: 0 },
      draw_money: { store_earnings_now: 0 },
      partner: { partner_direct_cnt: 0 },
      order: {
        order_all: 0,
        order_promotion: 0,
        order_pay: 0,
        unissued_order_cnt: 0,
        on_arrival_order_cnt: 0,
        dead_order_cnt: 0,
      },
    }, //会员信息
    isAlipay: true, //是否签约
    isInstructionModal: false, //是否显示伙伴说明弹窗
    userAgreement: "", //会员规则
  };

  // 获取签约信息
  getWorkerInfo = async () => {
    const res = await get_my_worker_info();
    if (res.data.length == 0) {
      this.setState({
        isAlipay: false,
      });
    }
  };

  // 获取会员首页数据
  getVipInfo = async () => {
    const res = await getVipInfo();
    this.setState({
      vipInfo: res,
    });
  };
  // 获取会员规则
  getUserAgreement = async () => {
    const res = await getUserAgreement({
      type: 4,
    });
    this.setState({
      userAgreement: res.content,
    });
  };
  // 打开伙伴说明弹窗
  handleInstructionModal = () => {
    this.setState({
      isInstructionModal: true,
    });
  };

  // 去登录
  Login = () => {
    if (!Taro.getStorageSync("session_key")) {
      Taro.reLaunch({
        url: "/pages/login/index",
      });
    }
  };
  componentDidShow() {
    if (Taro.getStorageSync("session_key")) {
      this.getVipInfo(); //获取会员首页数据
      this.getWorkerInfo(); //获取签约信息
    }
    this.getUserAgreement(); //获取会员规则
  }
  // 我的小店
  handleShopClick = () => {
    Taro.navigateTo({
      url: `/pages/memberSub/storeManagement/index?isManager=${true}`,
    });
    Taro.requestSubscribeMessage({
      tmplIds: ["vAYG7hbNbsD75YHpmGvF8O_Pve_1Q5AvnLBd-2JF9ys"],
      success: function (res) {
        console.log(res);
      },
    });
  };
  // 去我的伙伴
  handlePartnerClick = () => {
    Taro.navigateTo({
      url: `/pages/memberSub/myPartner/index`,
    });
    Taro.requestSubscribeMessage({
      tmplIds: ["vAYG7hbNbsD75YHpmGvF8O_Pve_1Q5AvnLBd-2JF9ys"],
      success: function (res) {
        console.log(res);
      },
    });
  };
  // 去订单列表
  handleOrderClick = (type) => {
    Taro.navigateTo({
      url: `/pages/memberSub/earningsOrder/index?type=${type}`,
    });
  };
  render() {
    const { vipInfo } = this.state;
    return (
      <View className="member">
        <View className="member-bg"></View>
        <View className="member-content">
          {/* 会员信息卡 */}
          <View className="member-info-card">
            <View className="member-info-card-header">
              <Image
                className="avatar"
                src={vipInfo.users.icon}
                mode="aspectFill"
              />

              <View className="member-info-card-header-text">
                <Text onClick={this.Login} className="user-name">
                  {vipInfo.users.name}
                </Text>

                <View className="member-info-card-header-text-level">
                  <Text className="level-text">店长</Text>
                  <Image className="level-icon" src={vip} />
                </View>
              </View>
            </View>
            <View className="member-info-card-content">
              {/* 捡漏计算器 */}
              <View
                onClick={() =>
                  Taro.navigateTo({
                    url: "/pages/calculatorSub/calculator/index",
                  })
                }
                className="my-shop"
              >
                <Image className="my-shop-icon" src={calculator} />
                <View className="my-shop-text">捡漏计算器</View>
              </View>
              {/* 我的小店 */}
              <View
                onClick={() => this.handleShopClick()}
                className="my-shop"
              >
                <Image className="my-shop-icon" src={home} />
                <View className="my-shop-text">我的小店</View>
              </View>
            </View>
          </View>
          {/* 预估收益 */}

          <View className="estimated-income">
            <Text className="estimated-income-title">预估收益</Text>
            <View className="estimated-income-content">
              <View className="income-item">
                <Text className="amount">
                  {vipInfo.earnings.store_earnings_now}
                </Text>
                <Text className="label">今日预估收益</Text>
              </View>
              <View className="divider"></View>
              <View className="income-item">
                <Text className="amount">
                  {vipInfo.earnings.store_earnings_all}
                </Text>
                <Text className="label">累计收益</Text>
              </View>
            </View>
            <view
              onClick={() =>
                Taro.navigateTo({
                  url: `/pages/memberSub/earningsDetail/index`,
                })
              }
              className="estimated-income-detail"
            >
              收益详情
              <Image className="to-detail" src={toDetail} />
            </view>
          </View>

          {/* 可提现金额 */}
          <View className="withdrawable-amount">
            <View className="withdrawable-amount-header">
              <Image className="withdrawable-amount-icon" src={withdrawable} />
              <Text className="withdrawable-amount-title">可提现金额</Text>
            </View>
            <View className="withdrawable-amount-content">
              <View className="left">
                <Text className="amount">
                  {`¥ ${vipInfo.draw_money.store_earnings_now}`}
                </Text>
                {(!this.state.isAlipay || vipInfo.users.user_identity_translate != 1) && (
                  <View className="warning-icon-box">
                    <Image className="warning-icon" src={warning} />
                    <Text className="warning-text">{vipInfo.users.user_identity_translate == 2 ? '认证失败' : vipInfo.users.user_identity_translate == 0 ? '未完成提现认证' : '认证中'}</Text>
                  </View>
                )}
              </View>
              <View
                onClick={() =>
                  Taro.navigateTo({ url: `/pages/memberSub/cashOut/index` })
                }
                className="right"
              >
                点击提现
              </View>
            </View>
          </View>
          {/* 我的伙伴 */}
          <View className="my-partner">
            <View className="my-partner-header">
              <View className="my-partner-header-left">
                <Image className="my-partner-icon" src={partner} />
                <Text className="my-partner-title">我的伙伴</Text>
              </View>
              <View
                onClick={() => this.handlePartnerClick()}
                className="my-partner-header-right"
              >
                查看更多
                <AtIcon
                  value="chevron-right"
                  size="10"
                  color="#A1A1A1"
                ></AtIcon>
              </View>
            </View>
            <View className="my-partner-content">
              {this.state.userAgreement && (
                <Image
                  onClick={() => this.handleInstructionModal()}
                  className="partnerExplain"
                  src="https://yushi.tos-cn-beijing.volces.com/calculator/partnerExplain.png"
                />
              )}
              <View
                onClick={() =>
                  Taro.navigateTo({ url: `/pages/memberSub/myPartner/index` })
                }
                className="my-partner-item"
              >
                <Text className="label">直接伙伴</Text>
                <Text className="number">
                  {vipInfo.partner?.partner_direct_cnt || 0}
                </Text>
              </View>
              {/* <View className="my-partner-item">
                <Text className="label">间接伙伴</Text>
                <Text className="number">{vipInfo.partner?.indirect_partner || 0}</Text>
              </View> */}
            </View>
          </View>
          {/* 今日订单 */}
          <View className="today-order">
            <View className="today-order-header">
              <View className="today-order-header-left">
                <Image className="today-order-icon" src={order} />
                <Text className="today-order-title">今日订单</Text>
              </View>
              <View
                onClick={() => this.handleOrderClick(2)}
                className="today-order-header-right"
              >
                历史订单
                <AtIcon
                  value="chevron-right"
                  size="10"
                  color="#A1A1A1"
                ></AtIcon>
              </View>
            </View>

            <View className="today-order-content">
              <View className="order-item">
                <Text className="label">订单总量</Text>
                <Text className="amount">{vipInfo.order.order_all}</Text>
              </View>
              <View
                className="order-item"
                onClick={() => this.handleOrderClick(2)}
              >
                <Text className="label">推广订单</Text>
                <Text className="amount">{vipInfo.order.order_promotion}</Text>
              </View>
              <View
                className="order-item"
                onClick={() => this.handleOrderClick(2)}
              >
                <Text className="label">已付款订单</Text>
                <Text className="amount">
                  {vipInfo.order.unissued_order_cnt}
                </Text>
              </View>
              <View
                className="order-item"
                onClick={() => this.handleOrderClick(2)}
              >
                <Text className="label">已收货订单</Text>
                <Text className="amount">
                  {vipInfo.order.on_arrival_order_cnt}
                </Text>
              </View>
              {/* <View
                className="order-item"
                onClick={() => this.handleOrderClick(2)}
              >
                <Text className="label">已结算订单</Text>
                <Text className="amount">{vipInfo.order.order_pay}</Text>
              </View> */}
              <View
                className="order-item"
                onClick={() => this.handleOrderClick(2)}
              >
                <Text className="label">已失效订单</Text>
                <Text className="amount">{vipInfo.order.dead_order_cnt}</Text>
              </View>
            </View>
          </View>
        </View>
        {/* 使用说明 */}
        <InstructionModal
          title="我的伙伴"
          content={this.state.userAgreement}
          isOpened={this.state.isInstructionModal}
          onClose={() => this.setState({ isInstructionModal: false })}
        />
      </View>
    );
  }
}
