import { Component } from 'react'
import { View, Text, Image } from '@tarojs/components'
import { AtList, AtListItem, AtModal, AtModalHeader, AtModalContent, AtModalAction, AtInput } from "taro-ui"
import './index.less'
import Taro from '@tarojs/taro'
import { get_my_worker_info, submit_withdraw_record } from '../../../service/money_api'
import { getUserInfo } from '../../../service/index'
export default class Index extends Component {
  state = {
    userInfo: {},
    isOpened: false,
    isAlipay: false, // 是否已绑定支付宝
    isBank: false, // 是否已绑定银行卡
    amount: '', // 提现金额
    bank_id: 0, // 银行卡id
    alipay_id: 0, // 支付宝id
    type: 0, // 提现类型
    translate_money: 0, // 可提现金额
  }
  componentDidMount () {
    this.getWorkerInfo(); // 页面加载时请求签约信息
    this.getUserInfo(); // 页面加载时请求用户信息
  }
  // 获取用户信息
  getUserInfo = async () => {
    const userInfoRes = await getUserInfo();
    this.setState({
      translate_money: userInfoRes.translate_money
    });
    console.log(userInfoRes, 'userInfoRes');

  }
  // 获取签约信息
  getWorkerInfo = async () => {
    const res = await get_my_worker_info();
    if (res.data.length > 0) {
      res.data.forEach(item => {
        if (item.rsv_account_type === 1) {
          this.setState({
            type: 1,
            isAlipay: true,
            alipay_id: item.id
          });
        } else {
          this.setState({
            type: 0,
            isBank: true,
            bank_id: item.id
          });
        }
      });
    }
    console.log(res, 'res');
  }


  openModal = () => {
    if (!this.state.isAlipay && !this.state.isBank) {
      Taro.showToast({
        title: '请先提现认证',
        icon: 'none'
      })
      return;
    }
    this.setState({
      isOpened: true
    })
  }
  handleChange = (e) => {
    let amount = e;
   
    let translate_money = parseFloat(this.state.translate_money);
    
    if (amount > translate_money) {
      amount = translate_money;
    }
    this.setState({
      amount: amount
    });
  }
  handleSubmit = async () => {
    if (this.state.amount <= 0) {
      Taro.showToast({
        title: '请输入大于0的金额',
        icon: 'none'
      })
      return;
    }
    console.log(this.state.alipay_id, 'this.state.alipay_id', this.state.bank_id, 'this.state.bank_id');

    const res = await submit_withdraw_record({
      amount: this.state.amount,
      bank_id: this.state.type === 1 ? this.state.alipay_id : this.state.bank_id
    });
    if (res.code === 200) {
      Taro.showToast({
        title: '提现申请成功',
        icon: 'success'
      })
    } else {
      Taro.showToast({
        title: `提现失败:${res.msg}`,
        icon: 'error'
      })
    }
    this.setState({
      isOpened: false
    })
    this.getUserInfo();
  }

  render () {
    return (
      <View className='index'>
        {/* 提现 */}
        <View className='cash-out'>
          <View className='balance-section'>
            <View className='balance-info'>
              <Text className='label'>可提现金额</Text>
              <View className='amount'>
                <Text className='integer'>{`¥ ${this.state.translate_money}`}</Text>
              </View>
            </View>
            <View className='action'>
              <View className='withdraw-btn' onClick={() => this.openModal()}>提现</View>
            </View>
          </View>
        </View>
        {/* 提现功能 */}
        <View className='cash-out-function'>
          <AtList hasBorder={false}>
            <AtListItem hasBorder={false} onClick={() => Taro.navigateTo({ url: `/pages/memberSub/Alipay/index` })} title='提现认证' arrow='right' />
            <View className='line'></View>
            <AtListItem hasBorder={false} onClick={() => Taro.navigateTo({ url: `/pages/memberSub/cashOutRecord/index` })} title='提现记录' extraText='' arrow='right' />
            {/* <View className='line'></View> */}
            {/* <AtListItem hasBorder={false} title='支付账户' extraText='需维护支付宝账户信息' arrow='right' /> */}
            {/* <View className='line'></View> */}
            {/* <AtListItem hasBorder={false} onClick={() => Taro.navigateTo({ url: `/pages/memberSub/statementRecords/index` })} title='标题结算单记录' extraText='6月结算单已出' arrow='right' /> */}
          </AtList>
        </View>
        {/* 结算单说明 */}
        <View className='settlement-statement'>
          <Text className='title'>结算单说明</Text>
          <View className='contentBox'>
            <View className='content indent'>1. 每月 <Text className='highlight'>27</Text>号 出上月结算单</View>
            <View className='content sub-content'>收益可在当月27号至30号全天申请提现</View>
            <View className='content sub-content'>错过需要等下个月,提现金额会在1-5个工作日到账</View>
            <View className='content indent'>2. 会员需要在提现前完成 提现认证 并审核通过</View>
            <View className='content sub-content'>维护完善 支付宝账户信息，否则将影响提现进行</View>
            <View className='content indent'>3. 结算单收益:订单完成时间在上个月的总收益</View>
            <View className='content sub-content'>上个月【已付款】但未完成订单可在下个月提现</View>
            <View className='content indent'>4. 可提现金额已扣除各项税费，提现金额需大于1元</View>
            <View className='content indent'>5. 本月未提现收益不会清 0</View>
            <View className='content sub-content'>会累积到账户余额，下个月合并提现</View>
          </View>
        </View>
        <AtModal
          isOpened={this.state.isOpened}
        >
          <AtModalHeader>提现申请</AtModalHeader>
          <AtModalContent>
            <View className='amount-box'>
              <AtInput
                className='amount-input'
                name='value2'
                title='金额'
                type='number'
                placeholder='请输入金额'
                value={this.state.amount}
                onChange={this.handleChange}
              />
              <View className='all-btn' onClick={() => this.handleChange(this.state.translate_money)}>全部</View>
            </View>
            <View className='amount-info'>
              {
                this.state.isAlipay &&
                <View className={['amount-info-item', this.state.type === 1 ? 'active' : '']} onClick={() => this.setState({ type: 1 })}>
                  <Image src='https://video-img.fyshark.com/1735041316314%E6%94%AF%E4%BB%98%E5%AE%9D%E6%94%AF%E4%BB%98.png' style={{ width: '24px', height: '24px' }} />
                  <Text className='amount-info-item-text'>支付宝</Text>
                </View>
              }
              {
                this.state.isBank &&
                <View className={['amount-info-item', this.state.type === 0 ? 'active' : '']} onClick={() => this.setState({ type: 0 })}>
                  <Image src='https://video-img.fyshark.com/1735041334363%E6%94%AF%E4%BB%98%E5%B9%B3%E5%8F%B0-%E9%93%B6%E8%81%94.png' style={{ width: '32px', height: '24px' }} />
                  <Text className='amount-info-item-text'>银行卡</Text>
                </View>
              }
            </View>
            <View className='submit-btn' onClick={this.handleSubmit}>
              <View className='submit-btn-text'>提交</View>
            </View>
          </AtModalContent>
          <AtModalAction>  </AtModalAction>
        </AtModal>
      </View>
    )
  }
}
